]> git.sesse.net Git - nageru/blobdiff - mixer.h
Send audio all the way through to the encoder and muxer.
[nageru] / mixer.h
diff --git a/mixer.h b/mixer.h
index b2561d15c0b395f2d82e2a5d92b682b7ab634942..9b631e4766071d35e6f0d215cd3f4442f46cdf2e 100644 (file)
--- a/mixer.h
+++ b/mixer.h
@@ -15,6 +15,7 @@
 #include "ref_counted_frame.h"
 #include "ref_counted_gl_sync.h"
 #include "theme.h"
+#include "resampler.h"
 
 #define NUM_CARDS 2
 
@@ -112,10 +113,12 @@ private:
                QSurface *surface;
                QOpenGLContext *context;
 
-               bool new_data_ready = false;  // Whether new_frame contains anything.
+               bool new_data_ready = false;  // Whether new_frame and new_frame_audio contains anything.
                RefCountedFrame new_frame;
                GLsync new_data_ready_fence;  // Whether new_frame is ready for rendering.
+               std::vector<float> new_frame_audio;
                std::condition_variable new_data_ready_changed;  // Set whenever new_data_ready is changed.
+               Resampler *resampler = nullptr;
        };
        CaptureCard cards[NUM_CARDS];  // protected by <bmusb_mutex>